@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,11 +22,11 @@
 #include "ui_drumgrid.h"
 #include "drumgridabout.h"
 
-#include <QtGui/QInputDialog>
-#include <QtGui/QShortcut>
-#include <QtGui/QToolTip>
-#include <QtCore/QSignalMapper>
-#include <QtCore/QSettings>
+#include <QInputDialog>
+#include <QShortcut>
+#include <QToolTip>
+#include <QSignalMapper>
+#include <QSettings>
 #include <qmath.h>
 #include "alsaclient.h"
 #include "alsaport.h"
