@@ -1,6 +1,6 @@
 /*
-    Virtual Piano Widget for Qt4
-    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Virtual Piano Widget for Qt5
+    Copyright (C) 2008-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,4 +21,9 @@
 
 typedef QHash<int, int> KeyboardMap;
 
+const int DEFAULTSTARTINGKEY = 9;
+const int DEFAULTBASEOCTAVE = 1;
+const int DEFAULTNUMBEROFKEYS = 88;
+const int KEYLABELFONTSIZE = 7;
+
 #endif // KEYBOARDMAP_H
