@@ -1,6 +1,6 @@
 /*
-    Virtual Piano Widget for Qt4
-    Copyright (C) 2008-2010, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Virtual Piano Widget for Qt5
+    Copyright (C) 2008-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,10 +19,12 @@
 #ifndef PIANODEFS_H
 #define PIANODEFS_H
 
-#if defined(VPIANO_PLUGIN)
-#define VPIANO_EXPORT Q_DECL_EXPORT
-#else
-#define VPIANO_EXPORT Q_DECL_IMPORT
-#endif
+//#if defined(VPIANO_PLUGIN)
+//#define VPIANO_EXPORT Q_DECL_EXPORT
+//#else
+//#define VPIANO_EXPORT Q_DECL_IMPORT
+//#endif
+
+#define VPIANO_EXPORT
 
 #endif // PIANODEFS_H
